@@ -44,6 +44,10 @@ struct MVMContainerSpec {
     /* Deserializes the container data, if any. */
     void (*deserialize) (MVMThreadContext *tc, MVMSTable *st, MVMSerializationReader *reader);
 
+    /* Called when the whole of the REPR data has been deserialized (so the
+     * offsets of attributes could be queried, for example). */
+    void (*post_deserialize) (MVMThreadContext *tc, MVMSTable *st);
+
     /* Returns a non-zero value if we can store to the container. */
     MVMint32 (*can_store) (MVMThreadContext *tc, MVMObject *cont);
 
@@ -63,6 +67,7 @@ struct MVMContainerSpec {
 /* A container configurer knows how to attach a certain type of container
  * to an STable and configure it. */
 struct MVMContainerConfigurer {
+    MVMString *name;
     /* Sets this container spec in place for the specified STable. */
     void (*set_container_spec) (MVMThreadContext *tc, MVMSTable *st);
 
@@ -70,17 +75,6 @@ struct MVMContainerConfigurer {
     void (*configure_container_spec) (MVMThreadContext *tc, MVMSTable *st, MVMObject *config);
 };
 
-/* Container registry is a hash mapping names of container configurations
- * to function tables. */
-struct MVMContainerRegistry {
-    MVMString              *name;
-    const MVMContainerConfigurer *configurer;
-
-    /* Inline handle to the hash in which this is stored. */
-    UT_hash_handle hash_handle;
-};
-
-MVM_PUBLIC void MVM_6model_add_container_config(MVMThreadContext *tc, MVMString *name, const MVMContainerConfigurer *configurer);
 const MVMContainerConfigurer * MVM_6model_get_container_config(MVMThreadContext *tc, MVMString *name);
 void MVM_6model_containers_setup(MVMThreadContext *tc);
 MVMint64 MVM_6model_container_iscont_rw(MVMThreadContext *tc, MVMObject *cont);
