@@ -7,9 +7,9 @@
  */
 
 /* Version information. */
-#define MVM_VERSION "2021.02"
+#define MVM_VERSION "2021.12"
 #define MVM_VERSION_MAJOR 2021
-#define MVM_VERSION_MINOR 02
+#define MVM_VERSION_MINOR 12
 #define MVM_VERSION_PATCH 0
 
 /* Various compiler-specific pragmii. */
@@ -55,11 +55,11 @@
 #define MVM_CAN_UNALIGNED_INT32
 #endif
 
-#if 0
+#if 1
 #define MVM_CAN_UNALIGNED_INT64
 #endif
 
-#if 0
+#if 1
 #define MVM_CAN_UNALIGNED_NUM64
 #endif
 
@@ -69,10 +69,42 @@
 #define MVM_HAS_SUBSTANDARD_POW
 #endif
 
+#if 0
+#define MVM_HAS_SUBSTANDARD_LOG
+#endif
+
+#if 0
+#define MVM_HAS_SUBSTANDARD_LOG10
+#endif
+
+#if 0
+#define MVM_HAS_SUBSTANDARD_ASIN
+#endif
+
+#if 0
+#define MVM_HAS_SUBSTANDARD_ACOS
+#endif
+
 #if 1
 #define MVM_BOOL _Bool
 #endif
 
+#if 1
+#define MVM_HAS_RDTSCP
+#endif
+
+#if 1
+#define MVM_HAS_ISINF
+#endif
+
+#if 1
+#define MVM_HAS_ISNAN
+#endif
+
+#if 1
+#define MVM_HAS_SIGNBIT
+#endif
+
 /* Should we translate \n to \r\n on output? */
 #define MVM_TRANSLATE_NEWLINE_OUTPUT 0
 
