@@ -5,8 +5,10 @@
 /* pthread_setname_np only exists if we set _GNU_SOURCE extremely early.
  * We will need to be vgilant to not accidentally use gnu extensions in
  * other places without checking properly. */
+#ifndef _GNU_SOURCE
 #define _GNU_SOURCE
 #endif
+#endif
 
 #include <stdarg.h>
 #include <stdio.h>
@@ -119,24 +121,31 @@ MVM_PUBLIC MVMint32 MVM_jit_support(void);
 #include "core/ptr_hash_table.h"
 #include "core/uni_hash_table.h"
 #include "core/threadcontext.h"
+#include "disp/registry.h"
+#include "disp/boot.h"
+#include "disp/inline_cache.h"
 #include "core/instance.h"
 #include "core/interp.h"
+#include "core/fixedsizealloc.h"
 #include "core/callsite.h"
 #include "core/args.h"
+#include "disp/program.h"
+#include "disp/syscall.h"
+#include "disp/resume.h"
 #include "core/alloc.h"
 #include "core/frame.h"
 #include "core/callstack.h"
 #include "core/validation.h"
+#include "core/ops.h"
+#include "core/ext.h"
 #include "core/bytecode.h"
 #include "core/bytecodedump.h"
-#include "core/ops.h"
 #include "core/threads.h"
 #include "core/hll.h"
 #include "core/loadbytecode.h"
 #include "core/bitmap.h"
 #include "math/num.h"
 #include "core/coerce.h"
-#include "core/ext.h"
 #ifdef HAVE_LIBFFI
 #include "core/nativecall_libffi.h"
 #else
@@ -164,6 +173,7 @@ MVM_PUBLIC MVMint32 MVM_jit_support(void);
 #include "core/regionalloc.h"
 #include "spesh/dump.h"
 #include "spesh/debug.h"
+#include "spesh/disp.h"
 #include "spesh/graph.h"
 #include "spesh/codegen.h"
 #include "spesh/manipulate.h"
@@ -184,7 +194,6 @@ MVM_PUBLIC MVMint32 MVM_jit_support(void);
 #include "spesh/stats.h"
 #include "spesh/plan.h"
 #include "spesh/arg_guard.h"
-#include "spesh/plugin.h"
 #include "spesh/frame_walker.h"
 #include "strings/nfg.h"
 #include "strings/normalize.h"
@@ -196,7 +205,6 @@ MVM_PUBLIC MVMint32 MVM_jit_support(void);
 #include "strings/utf16.h"
 #include "strings/iter.h"
 #include "strings/ops.h"
-#include "core/fixedsizealloc.h"
 #include "io/procops.h"
 #include "core/str_hash_table_funcs.h"
 #include "core/fixkey_hash_table_funcs.h"
